From: Stephen Rothwell <sfr@canb•auug.org.au>
To: Russell King <rmk@arm•linux.org.uk>
Cc: linux-next@vger•kernel.org, linux-kernel@vger•kernel.org,
Will Deacon <will.deacon@arm•com>,
Jason Baron <jbaron@redhat•com>,
Andrew Morton <akpm@linux-foundation•org>
Subject: linux-next: manual merge of the arm tree with Linus' tree
Date: Mon, 26 Mar 2012 11:05:50 +1100 [thread overview]
Message-ID: <20120326110550.5029ac4c49c2be2e2e0381cf@canb.auug.org.au> (raw)
[-- Attachment #1: Type: text/plain, Size: 2079 bytes --]
Hi Russell,
Today's linux-next merge of the arm tree got a conflict in
arch/arm/kernel/process.c between commit 909af768e888 ("coredump: remove
VM_ALWAYSDUMP flag") from the tree and commit e19d478e808e ("ARM:
7294/1: vectors: use gate_vma for vectors user mapping") from the arm
tree.
I fixed it up (see below) and can carry the fix as necessary.
--
Cheers,
Stephen Rothwell sfr@canb•auug.org.au
diff --cc arch/arm/kernel/process.c
index d3eca45,1531480..0000000
--- a/arch/arm/kernel/process.c
+++ b/arch/arm/kernel/process.c
@@@ -529,17 -531,36 +529,35 @@@ unsigned long arch_randomize_brk(struc
#ifdef CONFIG_MMU
/*
* The vectors page is always readable from user space for the
* atomic helpers and the signal restart code. Let's declare a mapping
* for it so it is visible through ptrace and /proc/<pid>/mem.
*/
+ static struct vm_area_struct gate_vma;
- int vectors_user_mapping(void)
+ static int __init gate_vma_init(void)
{
- struct mm_struct *mm = current->mm;
- return install_special_mapping(mm, 0xffff0000, PAGE_SIZE,
- VM_READ | VM_EXEC |
- VM_MAYREAD | VM_MAYEXEC | VM_RESERVED,
- NULL);
+ gate_vma.vm_start = 0xffff0000;
+ gate_vma.vm_end = 0xffff0000 + PAGE_SIZE;
+ gate_vma.vm_page_prot = PAGE_READONLY_EXEC;
+ gate_vma.vm_flags = VM_READ | VM_EXEC |
- VM_MAYREAD | VM_MAYEXEC |
- VM_ALWAYSDUMP;
++ VM_MAYREAD | VM_MAYEXEC;
+ return 0;
+ }
+ arch_initcall(gate_vma_init);
+
+ struct vm_area_struct *get_gate_vma(struct mm_struct *mm)
+ {
+ return &gate_vma;
+ }
+
+ int in_gate_area(struct mm_struct *mm, unsigned long addr)
+ {
+ return (addr >= gate_vma.vm_start) && (addr < gate_vma.vm_end);
+ }
+
+ int in_gate_area_no_mm(unsigned long addr)
+ {
+ return in_gate_area(NULL, addr);
}
const char *arch_vma_name(struct vm_area_struct *vma)
[-- Attachment #2: Type: application/pgp-signature, Size: 836 bytes --]
next reply other threads:[~2012-03-26 0:06 UTC|newest]
Thread overview: 39+ messages / expand[flat|nested] mbox.gz Atom feed top
2012-03-26 0:05 Stephen Rothwell [this message]
-- strict thread matches above, loose matches on Subject: below --
2025-03-26 23:50 linux-next: manual merge of the arm tree with Linus' tree Stephen Rothwell
2022-03-08 22:35 Stephen Rothwell
2020-05-27 23:09 Stephen Rothwell
2020-05-27 23:22 ` Russell King - ARM Linux admin
2020-05-28 7:01 ` Ard Biesheuvel
2020-05-30 8:41 ` Russell King - ARM Linux admin
2020-05-30 8:51 ` Ard Biesheuvel
2020-05-30 9:17 ` Russell King - ARM Linux admin
2020-05-30 9:53 ` Stephen Rothwell
2020-05-30 10:25 ` Ard Biesheuvel
2016-06-01 0:07 Stephen Rothwell
2016-06-01 8:52 ` Russell King
2012-03-30 0:11 Stephen Rothwell
2012-03-13 0:08 Stephen Rothwell
2012-03-13 6:16 ` Ingo Molnar
2012-03-13 8:33 ` Russell King
2012-03-13 8:36 ` Ingo Molnar
2012-03-13 8:47 ` Russell King
2012-03-13 8:56 ` Ingo Molnar
2012-03-13 9:00 ` Russell King
2012-03-13 8:48 ` Ingo Molnar
2012-03-13 8:58 ` Russell King
2012-03-13 9:06 ` Ingo Molnar
2012-03-13 9:09 ` Russell King
2012-03-13 9:11 ` Russell King
2012-01-29 23:38 Stephen Rothwell
2012-01-08 23:53 Stephen Rothwell
2012-01-08 23:53 linux-next: manual merge of the arm tree with Linus tree Stephen Rothwell
2012-01-08 23:53 linux-next: manual merge of the arm tree with Linus' tree Stephen Rothwell
2011-12-20 23:08 Stephen Rothwell
2011-09-21 0:33 Stephen Rothwell
2011-09-21 9:31 ` Linus Walleij
2010-07-13 0:51 Stephen Rothwell
2010-03-03 23:49 Stephen Rothwell
2010-03-04 1:16 ` Eric Miao
2010-03-03 23:33 Stephen Rothwell
2009-07-31 0:33 Stephen Rothwell
2009-07-31 0:41 ` H Hartley Sweeten
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20120326110550.5029ac4c49c2be2e2e0381cf@canb.auug.org.au \
--to=sfr@canb$(echo .)auug.org.au \
--cc=akpm@linux-foundation$(echo .)org \
--cc=jbaron@redhat$(echo .)com \
--cc=linux-kernel@vger$(echo .)kernel.org \
--cc=linux-next@vger$(echo .)kernel.org \
--cc=rmk@arm$(echo .)linux.org.uk \
--cc=will.deacon@arm$(echo .)com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
Be sure your reply has a Subject: header at the top and a blank line
@@@ -529,17 -531,36 +529,35 @@@ unsigned long arch_randomize_brk(struc
/*
* The vectors page is always readable from user space for the
- * atomic helpers and the signal restart code. Let's declare a mapping
- * for it so it is visible through ptrace and /proc/<pid>/mem.
+ * atomic helpers and the signal restart code. Insert it into the
+ * gate_vma so that it is visible through ptrace and /proc/<pid>/mem.
*/
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox